##  Fixing Integration Issues with SAP LeanIX AI Capabilities
SaaS discovery leverages AI to classify integration errors and suggest solutions for user input errors. Whenever an error from an integration occurs, it is classified into one of the following types:
  * User input error
  * System error
  * Internal error


This classification helps you determine if resolving the error is feasible. While system errors are beyond your control, for internal errors, SAP LeanIX has proactive monitoring set up to enable prompt action when required.
AI capability is also used to suggest solutions for user input errors. For instance, when an error message is technical and rather cryptic, AI translates it into a clear solution description. This simplification makes the issue resolution process easier, even for non-technical users.
![Example Error Message with an AI-Generated Solution Suggestion](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b20dd7a441014b27bfeb4dfd1269e_LowRes.png)
Example Error Message with an AI-Generated Solution Suggestion
